Struct BasicComposer

pub struct BasicComposer { /* private fields */ }
A basic composer implementation for converting events to nodes

Implementations

Source

impl BasicComposer

pub fn new(input: String) -> Self

Create a new composer from input string

pub fn with_limits(input: String, limits: Limits) -> Self

Create a new composer with custom limits

pub fn new_eager(input: String) -> Self

Create a new composer with eager parsing (for compatibility)

pub fn new_eager_with_limits(input: String, limits: Limits) -> Self

Create a new composer with eager parsing and custom limits