pub struct BasicComposer { /* private fields */ }Expand description
A basic composer implementation for converting events to nodes
Implementations
Sourceimpl BasicComposer
impl BasicComposer
Sourcepub fn with_limits(input: String, limits: Limits) -> Self
pub fn with_limits(input: String, limits: Limits) -> Self
Create a new composer with custom limits
Sourcepub fn new_eager(input: String) -> Self
pub fn new_eager(input: String) -> Self
Create a new composer with eager parsing (for compatibility)
Sourcepub fn new_eager_with_limits(input: String, limits: Limits) -> Self
pub fn new_eager_with_limits(input: String, limits: Limits) -> Self
Create a new composer with eager parsing and custom limits